## CSS - Demos - Alerts

<script type="module" src="/web_components/js/css/demos/WebC__CSS__Demo__Alerts.mjs"></script>

<webc-container>
    <webc-css-demo-alerts        ></webc-css-demo-alerts> 
    <webc-css-demo-alerts no-css ></webc-css-demo-alerts>
    
</webc-container>